==> hs-haskeline-0.6.4.7_1.tbz: lib/ghc-7.4.1/cabal/haskeline-0.6.4.7/register.sh <==
#!/bin/sh
echo 'name: haskeline
version: 0.6.4.7
id: haskeline-0.6.4.7-6a1d0c679e5d30cdab04da42a2aed022

license: BSD3
copyright: (c) Judah Jacobson
maintainer: Judah Jacobson <judah.jacobson@gmail.com>
stability: Experimental
homepage: http://trac.haskell.org/haskeline
package-url:
synopsis: A command-line interface for user input, written in Haskell.
description: Haskeline provides a user interface for line input in command-line
             programs.  This library is similar in purpose to readline, but since
             it is written in Haskell it is (hopefully) more easily used in other
             Haskell programs.
             .
             Haskeline runs both on POSIX-compatible systems and on Windows.
category: User Interfaces
author: Judah Jacobson
exposed: True
exposed-modules: System.Console.Haskeline
                 System.Console.Haskeline.Completion
                 System.Console.Haskeline.Encoding
                 System.Console.Haskeline.MonadException
                 System.Console.Haskeline.History System.Console.Haskeline.IO
hidden-modules: System.Console.Haskeline.Backend.WCWidth
                System.Console.Haskeline.Backend.Posix
                System.Console.Haskeline.Backend.IConv
                System.Console.Haskeline.Backend.DumbTerm
                System.Console.Haskeline.Backend System.Console.Haskeline.Command
                System.Console.Haskeline.Command.Completion
                System.Console.Haskeline.Command.History
                System.Console.Haskeline.Command.KillRing
                System.Console.Haskeline.Directory System.Console.Haskeline.Emacs
                System.Console.Haskeline.InputT System.Console.Haskeline.Key
                System.Console.Haskeline.LineState System.Console.Haskeline.Monads
                System.Console.Haskeline.Prefs System.Console.Haskeline.RunCommand
                System.Console.Haskeline.Term System.Console.Haskeline.Command.Undo
                System.Console.Haskeline.Vi
trusted: False
import-dirs: /usr/local/lib/ghc-7.4.1/cabal/haskeline-0.6.4.7
library-dirs: /usr/local/lib/ghc-7.4.1/cabal/haskeline-0.6.4.7
              /usr/local/lib
hs-libraries: HShaskeline-0.6.4.7
extra-libraries: iconv
extra-ghci-libraries:
include-dirs: /usr/local/include
              /usr/local/lib/ghc-7.4.1/cabal/haskeline-0.6.4.7/include
includes: h_iconv.h
depends: base-4.5.0.0-1a022b3476300ed3e5bfdd46dd7221d0
         bytestring-0.9.2.1-e2bcd9910229fcb291a3a8dd6f79f7fe
         containers-0.4.2.1-7c54595400348f577b3b4a45691c5afd
         directory-1.1.0.2-295465228776dcfcc680f61dc2cbcb59
         extensible-exceptions-0.1.1.4-d27a1ac47e54880cae007cceceb41580
         filepath-1.3.0.0-674b8a582fb49f1c9724f50a6a5d5768
         mtl-2.1.1-ae9b44386a2528180e60dcf2412689c0
         unix-2.5.1.0-5e7f658e8f4f1f2b2726f931e4676f5a
         utf8-string-0.3.7-ffaf35c0993df0e6545d3ec2d2884058
hugs-options:
cc-options:
ld-options:
framework-dirs:
frameworks:
haddock-interfaces: /usr/local/share/doc/ghc-7.4.1/cabal/haskeline-0.6.4.7/html/haskeline.haddock
haddock-html: /usr/local/share/doc/ghc-7.4.1/cabal/haskeline-0.6.4.7/html
' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-conf' "$@"

==> hs-haskeline-0.7.0.3.tbz: lib/ghc-7.4.2/cabal/haskeline-0.7.0.3/register.sh <==
#!/bin/sh
echo 'name: haskeline
version: 0.7.0.3
id: haskeline-0.7.0.3-9bd681967de153a9b159ba82d3bdbe03

license: BSD3
copyright: (c) Judah Jacobson
maintainer: Judah Jacobson <judah.jacobson@gmail.com>
stability: Experimental
homepage: http://trac.haskell.org/haskeline
package-url:
synopsis: A command-line interface for user input, written in Haskell.
description: Haskeline provides a user interface for line input in command-line
             programs.  This library is similar in purpose to readline, but since
             it is written in Haskell it is (hopefully) more easily used in other
             Haskell programs.
             .
             Haskeline runs both on POSIX-compatible systems and on Windows.
category: User Interfaces
author: Judah Jacobson
exposed: True
exposed-modules: System.Console.Haskeline
                 System.Console.Haskeline.Completion
                 System.Console.Haskeline.MonadException
                 System.Console.Haskeline.History System.Console.Haskeline.IO
hidden-modules: System.Console.Haskeline.Recover
                System.Console.Haskeline.Backend.Posix
                System.Console.Haskeline.Backend.Posix.Encoder
                System.Console.Haskeline.Backend.DumbTerm
                System.Console.Haskeline.Backend
                System.Console.Haskeline.Backend.WCWidth
                System.Console.Haskeline.Command
                System.Console.Haskeline.Command.Completion
                System.Console.Haskeline.Command.History
                System.Console.Haskeline.Command.KillRing
                System.Console.Haskeline.Directory System.Console.Haskeline.Emacs
                System.Console.Haskeline.InputT System.Console.Haskeline.Key
                System.Console.Haskeline.LineState System.Console.Haskeline.Monads
                System.Console.Haskeline.Prefs System.Console.Haskeline.RunCommand
                System.Console.Haskeline.Term System.Console.Haskeline.Command.Undo
                System.Console.Haskeline.Vi
trusted: False
import-dirs: /usr/local/lib/ghc-7.4.2/cabal/haskeline-0.7.0.3
library-dirs: /usr/local/lib/ghc-7.4.2/cabal/haskeline-0.7.0.3
              /usr/local/lib
hs-libraries: HShaskeline-0.7.0.3
extra-libraries:
extra-ghci-libraries:
include-dirs: /usr/local/include
includes:
depends: base-4.5.1.0-f58939ca866a8377999e7a71aa62d1d0
         bytestring-0.9.2.1-4cc8a513193316dfe32ba33f47609c9d
         containers-0.4.2.1-75f143aa39a3e77a1ce2300025bdd8ce
         directory-1.1.0.2-9e375ee7bfb1a0ae28bfd926af73e15a
         filepath-1.3.0.0-f998e5510c76a98913f57b14b4f16c57
         transformers-0.3.0.0-8e66ecc7d4dae2b07b2b5406908c70e4
         unix-2.5.1.1-56b0b11ddb32a213f6d73865d709e743
hugs-options:
cc-options:
ld-options:
framework-dirs:
frameworks:
haddock-interfaces: /usr/local/share/doc/ghc-7.4.2/cabal/haskeline-0.7.0.3/html/haskeline.haddock
haddock-html: /usr/local/share/doc/ghc-7.4.2/cabal/haskeline-0.7.0.3/html
' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-conf' "$@"
